@@ -2,13 +2,12 @@ import logging
 import os
 import pickle
 import random
+import warnings
 from functools import partial
 from collections import defaultdict
 from multiprocessing.pool import Pool
-from datetime import datetime
 
 import numpy as np
-import pandas as pd
 import pyarrow.parquet as pq
 import torch
 from torch.utils.data import WeightedRandomSampler, Sampler, Dataset
@@ -16,7 +15,7 @@ from torch.utils.data.dataloader import DataLoader
 
 from ptls.data_load.augmentations.all_time_shuffle import AllTimeShuffle
 from ptls.data_load.iterable_processing_dataset import IterableProcessingDataset
-from ptls.trx_encoder import PaddedBatch
+from ptls.data_load.padded_batch import PaddedBatch
 
 
 logger = logging.getLogger(__name__)
@@ -549,6 +548,8 @@ def create_train_loader(dataset, params):
 
 
 class MapStyleDatasetWrapper(torch.utils.data.Dataset):
+    """Deprecated. Use ptls.data_load.datasets.memory_dataset.MemoryMapDataset
+    """
     def __init__(self, data):
         self.data = data
 
@@ -560,7 +561,10 @@ class MapStyleDatasetWrapper(torch.utils.data.Dataset):
 
 
 class IterableDatasetWrapper(torch.utils.data.IterableDataset):
+    """Deprecated. Use ptls.data_load.datasets.memory_dataset.MemoryIterableDataset
+    """
     def __init__(self, data):
+        warnings.warn('Multiply data in multiprocessing mode', UserWarning)
         self.data = data
 
     def __iter__(self):
@@ -568,6 +572,9 @@ class IterableDatasetWrapper(torch.utils.data.IterableDataset):
 
 
 def create_validation_loader(dataset, params):
+    """Deprecated
+
+    """
     dataset = DropoutTrxDataset(dataset, 0, params.max_seq_len)
 
     if dataset.style == 'iterable':
@@ -605,6 +612,16 @@ class augmentation_chain:
         return x
 
 
+class AugmentationChain:
+    def __init__(self, f_augmentations):
+        self.f_augmentations = f_augmentations if f_augmentations is not None else []
+
+    def __call__(self, x):
+        for f in self.f_augmentations:
+            x = f(x)
+        return x
+
+
 class IterableAugmentations(IterableProcessingDataset):
     def __init__(self, a_chain):
         super().__init__()
