@@ -1,9 +1,11 @@
 import random
-import math
+
 import numpy as np
 
+from ptls.data_load.feature_dict import FeatureDict
 
-class RandomSlice:
+
+class RandomSlice(FeatureDict):
     def __init__(self, min_len, max_len, rate_for_min=1.0):
         super().__init__()
 
@@ -12,10 +14,10 @@ class RandomSlice:
         self.rate_for_min = rate_for_min
 
     def __call__(self, x):
-        seq_len = len(next(iter(x.values())))
+        seq_len = self.get_seq_len(x)
 
         idx = self.get_idx(seq_len)
-        new_x = {k: v[idx] for k, v in x.items()}
+        new_x = self.seq_indexing(x, idx)
         return new_x
 
     def get_idx(self, seq_len):
