@@ -10,6 +10,7 @@ client_1          -> client_1_features, client_1_id
 client_2          -> client_2_features, client_2_id
 """
 import logging
+import warnings
 
 import numpy as np
 import pytorch_lightning as pl
@@ -25,7 +26,7 @@ from ptls.data_load.iterable_processing.feature_filter import FeatureFilter
 from ptls.data_load.iterable_processing.iterable_shuffle import IterableShuffle
 from ptls.data_load.iterable_processing.seq_len_filter import SeqLenFilter
 from ptls.data_load.list_splitter import ListSplitter
-from ptls.data_load.parquet_dataset import ParquetDataset, ParquetFiles
+from ptls.data_load.datasets.parquet_dataset import ParquetDataset, ParquetFiles
 from ptls.data_load.partitioned_dataset import PartitionedDataset, PartitionedDataFiles
 
 logger = logging.getLogger(__name__)
@@ -40,6 +41,9 @@ def cpc_collate_fn(batch):
 
 class CpcDataModuleTrain(pl.LightningDataModule):
     def __init__(self, type, setup, train, valid, pl_module):
+        warnings.warn('Use `ptls.frames.PtlsDataModule` '
+                      'with `ptls.frames.cpc.CpcDataset` or `ptls.frames.cpc.CpcIterableDataset`',
+                      DeprecationWarning)
         super().__init__()
 
         self._type = type
