@@ -1,6 +1,7 @@
 """
 This class inherited from ColesDataModuleTrain. Just rewrited collate function
 """
+import warnings
 
 """
 Creates data loaders for contrastive learning
@@ -19,14 +20,12 @@ client_k          -> [client_k_smpl_1, client_k_smpl_2, ..., client_k_smpl_n]
 
 import logging
 
-import pytorch_lightning as pl
 import torch
 
 from collections import defaultdict
 from torch.utils.data import DataLoader
-from tqdm.auto import tqdm
 
-from ptls.trx_encoder import PaddedBatch
+from ptls.data_load.padded_batch import PaddedBatch
 from ptls.data_load.data_module.coles_data_module import ColesDataModuleTrain
 
 import torch.multiprocessing
@@ -67,6 +66,9 @@ def collate_fn(batch):
 
 class CpcV2DataModuleTrain(ColesDataModuleTrain):
     def __init__(self, type, setup, train, valid, pl_module):
+        warnings.warn('Use `ptls.frames.PtlsDataModule` '
+                      'with `ptls.frames.cpc.CpcV2Dataset` or `ptls.frames.cpc.CpcV2IterableDataset`',
+                      DeprecationWarning)
         super().__init__(type, setup, train, valid, pl_module)
 
     def train_dataloader(self):
