@@ -17,8 +17,8 @@ client_2          -> (client_2_smpl_1_left, client_2_smpl_3_right), 0
 """
 import logging
 import random
+import warnings
 
-import numpy as np
 import pytorch_lightning as pl
 import torch
 
@@ -33,9 +33,10 @@ from ptls.data_load.iterable_processing.feature_filter import FeatureFilter
 from ptls.data_load.iterable_processing.iterable_shuffle import IterableShuffle
 from ptls.data_load.iterable_processing.seq_len_filter import SeqLenFilter
 from ptls.data_load.list_splitter import ListSplitter
-from ptls.data_load.parquet_dataset import ParquetDataset, ParquetFiles
+from ptls.data_load.datasets.parquet_dataset import ParquetDataset, ParquetFiles
 from ptls.data_load.partitioned_dataset import PartitionedDataset, PartitionedDataFiles
-from ptls.metric_learn.dataset import split_strategy, nested_list_to_flat_with_collate
+from ptls.metric_learn.dataset import nested_list_to_flat_with_collate
+from ptls.frames.coles import split_strategy
 from ptls.metric_learn.dataset.splitting_dataset import IterableSplittingDataset, MapSplittingDataset
 
 logger = logging.getLogger(__name__)
@@ -59,12 +60,15 @@ def collate_nsp_pairs(batch):
             padded_collate_wo_target(lefts),
             padded_collate_wo_target(rights)
         ),
-        targets.float(),
+        targets.long(),
     )
 
 
 class NspDataModuleTrain(pl.LightningDataModule):
     def __init__(self, type, setup, train, valid, pl_module):
+        warnings.warn('Use `ptls.frames.PtlsDataModule` '
+                      'with `ptls.frames.bert.NspDataset` or `ptls.frames.bert.NspIterableDataset`',
+                      DeprecationWarning)
         super().__init__()
 
         self._type = type
