@@ -10,16 +10,15 @@ client_1          -> client_1_features, client_1_id
 client_2          -> client_2_features, client_2_id
 """
 import logging
+import warnings
 from functools import partial
 
-import numpy as np
 import pytorch_lightning as pl
 import torch
-from pyhocon.config_parser import ConfigFactory
 from torch.utils.data import DataLoader
 from tqdm.auto import tqdm
 
-from ptls.data_load import IterableAugmentations, IterableChain, augmentation_chain, padded_collate_wo_target
+from ptls.data_load import IterableAugmentations, IterableChain, padded_collate_wo_target
 from ptls.data_load.augmentations.build_augmentations import build_augmentations
 from ptls.data_load.data_module.map_augmentation_dataset import MapAugmentationDataset
 from ptls.data_load.iterable_processing.category_size_clip import CategorySizeClip
@@ -27,9 +26,9 @@ from ptls.data_load.iterable_processing.feature_filter import FeatureFilter
 from ptls.data_load.iterable_processing.iterable_shuffle import IterableShuffle
 from ptls.data_load.iterable_processing.seq_len_filter import SeqLenFilter
 from ptls.data_load.list_splitter import ListSplitter
-from ptls.data_load.parquet_dataset import ParquetDataset, ParquetFiles
+from ptls.data_load.datasets.parquet_dataset import ParquetDataset, ParquetFiles
 from ptls.data_load.partitioned_dataset import PartitionedDataset, PartitionedDataFiles
-from ptls.trx_encoder import PaddedBatch
+from ptls.data_load.padded_batch import PaddedBatch
 
 logger = logging.getLogger(__name__)
 
@@ -52,11 +51,14 @@ def collate_rtd_batch(batch, replace_prob, skip_first=0):
     for k, v in new_x.items():
         v.flatten()[to_replace_flatten] = v.flatten()[sampled_trx_ids]
 
-    return PaddedBatch(new_x, lengths), to_replace.long().float().flatten()[mask.flatten().bool()]
+    return PaddedBatch(new_x, lengths), to_replace.long().flatten()[mask.flatten().bool()]
 
 
 class RtdDataModuleTrain(pl.LightningDataModule):
     def __init__(self, type, setup, train, valid, pl_module, replace_token=False):
+        warnings.warn('Use `ptls.frames.PtlsDataModule` '
+                      'with `ptls.frames.bert.RtdDataset` or `ptls.frames.bert.RtdIterableDataset`',
+                      DeprecationWarning)
         super().__init__()
 
         self._type = type
